@@ -3,7 +3,7 @@
 #                                                                         #
 # The purpose of the caterpillar.plot function is to provide a            #
 # caterpillar plot of the posterior summaries in an object of class       #
-# demonoid or laplace, or also of S x J matrix of S samples and J         #
+# demonoid, laplace, or pmc, or also of S x J matrix of S samples and J   #
 # variables.                                                              #
 ###########################################################################
 
@@ -169,6 +169,50 @@ caterpillar.plot <- function(x, Parms=NULL, Title=NULL)
           axis(2, labels=rownames(x), tick=FALSE, las=1,
                at=yy, cex.axis=cex.labels)
           }
+     else if(identical(class(x), "pmc")) {
+          x <- x$Summary
+          x.lab <- "All Samples"
+          if(!is.null(Parms)) {
+               if(is.character(Parms)) {
+                    Parms <- sub("\\[","\\\\[",Parms)
+                    Parms <- sub("\\]","\\\\]",Parms)
+                    Parms <- sub("\\.","\\\\.",Parms)
+                    if(length(grep(Parms[1], rownames(x))) == 0)
+                         stop("Parameter in Parms does not exist.")
+                    keeprows <- grep(Parms[1], rownames(x))
+                    if(length(Parms) > 1) {
+                         for (i in 2:length(Parms)) {
+                              if(length(grep(Parms[i], rownames(x))) == 0)
+                                   stop("Parameter in Parms does not exist.")
+                              keeprows <- c(keeprows,
+                                   grep(Parms[i], rownames(x)))}
+                         }
+                    }
+               if(is.numeric(Parms)) keeprows <- Parms
+               temp <- x
+               x <- matrix(x[keeprows,], length(keeprows), ncol(temp))
+               rownames(x) <- rownames(temp)[keeprows]
+               colnames(x) <- colnames(temp)
+               }
+          ### Setup
+          x.rows <- nrow(x)
+          x.lim <- c(min(x[,5]), max(x[,7]))
+          y.lim <- c(0, x.rows+1)
+          ### Basic Plot
+          plot(0, 0, ylim=y.lim, xlim=x.lim, main=Title, sub="",
+               xlab=x.lab, ylab="", type="n", ann=TRUE, yaxt="n")
+          abline(v=0, col="gray")
+          ### Add Medians
+          points(x[,6], x.rows:1, pch=20)
+          ### Add Horizontal Lines for 2.5%-97.5% Quantiles
+          for (i in 1:x.rows) {
+               lines(x[i,c(5,7)], c(x.rows-i+1, x.rows-i+1))}
+          ### Add y-axis labels
+          yy <- x.rows:1
+          cex.labels <- 1 / {log(x.rows)/5 + 1}
+          axis(2, labels=rownames(x), tick=FALSE, las=1, at=yy,
+               cex.axis=cex.labels)
+          }
      else {
           x <- as.matrix(x)
           x.hpd <- p.interval(x, HPD=TRUE, MM=FALSE, prob=0.95)
